﻿using System;
using System.Net;
using MoqTestExample.DataAccess;

namespace MoqTestExample
{
    public class Basket
    {
        private readonly IBasketDal _basketDal;

        public Basket(IBasketDal basketDal)
        {
            _basketDal = basketDal;
        }

        public Basket()
        {
            
        }

        /// <summary>
        /// Calculates the basket totals.
        /// </summary>
        /// <param name="customerId">The customer id.</param>
        public virtual DataAccess.Basket CalculateBasketTotals(int customerId)
        {
            // Retrieve the basket
            DataAccess.Basket basket = _basketDal.GetBasket(customerId);

            // Get the customer name
            string customerName = _basketDal.GetCustomerName(customerId);

            // Set the customer name
            basket.CustomerName = customerName;

            // Add the shipping price to the basket.
            basket.Total += basket.ShippingPrice;

            return basket;

        }

        /// <summary>
        /// Calls the Geolocation service and adds the details
        /// to our basket object.
        /// </summary>
        /// <param name="basket"></param>
        /// <param name="ipAddress"></param>
        /// <returns></returns>
        public virtual DataAccess.Basket 
                GetGeoLocationHtmlForBasket(DataAccess.Basket basket, 
                                            string ipAddress)
        {
            basket.GeoLocationHtml = GeoLocationLookup(ipAddress);

            return basket;
        }

        /// <summary>
        /// Call a 3rd party service to get the Ip address location
        /// </summary>
        public virtual string GeoLocationLookup(string ipAddress)
        {
            string result;
            using (var webClient = new WebClient())
            {
                result = webClient.DownloadString(String.Format("http://api.hostip.info/get_html.php?ip={0}&position=true", ipAddress));
            }

            return result;
        }
    }
}
